=======
History
=======

0.4.0 (2016-3-08)
-----------------

* support 204 no content HTTP return code
* fix naming of _validate_token method
* update Sphynx dependency
* full unit tests coverage
* fix return on POST, PUT and DELETE operations
* fix use of custom BASE API URL

0.3.0 (2016-2-18)
-----------------

* implement exceptions handling
* docstrings and documentation
* Housekeeping and refactoring
* Better CI setup
* Sphynx doc and readthedocs.org publishing.

0.2.0 (2016-2-09)
-----------------

* Minor fixes.

0.1.0 (2016-2-09)
-----------------

* First release on PyPI.
